::  *********************************************************************************************
::  ********                                 Upgrade.bat                                 ********
::  ********  Automates the process for firmware installation on production K2 machines  ********
::  *********************************************************************************************
::
::  Variables
::      SEQUENCE - A string containing the upgrade process' sequence of steps in order from first to last
::      SOURCE   - Contains the drive and path (does not include trailing "\") of the directory that the firmware files will be copied from
::      TARGET   - Contains the drive and path (does not include trailing "\") of the directory where the firmware backup files will be stored
::
::  *********************************************************************************************


@ECHO OFF


TITLE K2 Firmware Installation Program


SETLOCAL ENABLEEXTENSIONS ENABLEDELAYEDEXPANSION


:::::::::::::::::::::::::::::::::::::::::
::  INITIALIZATION AND VARIABLE SETUP  ::
:::::::::::::::::::::::::::::::::::::::::
:INIT

    SET COMMIT=1
    SET DONTCOMMIT=0
    SET EXENAME=C:\PRO2010NET.EXE
    SET FILEDATE=01/01/2007
    SET NEEDYEAR=2013
    IF EXIST %EXENAME% (
        FOR %%? IN (%EXENAME%) DO SET FILEDATE=%%~t?
    )
    SET EXEYEAR=%FILEDATE:~6,4%
    REM ECHO %EXEYEAR%
    REM ECHO %NEEDYEAR%
    IF %EXEYEAR% GEQ %NEEDYEAR% (
       SET COMMIT=0
    )
    REM ECHO %COMMIT%
    IF %COMMIT%  NEQ %DONTCOMMIT% (
        ECHO Need to commit
    ) ELSE  (ECHO Don't Need to commit)

    IF "%~d0"=="E:" (
        SET SOURCE=%~dp0
        SET SOURCE=!SOURCE:~0,-1!
        IF EXIST C:\WINDOWS\system32\EWFMGR.EXE (
            SET TARGET=C:\Firmware
            IF EXIST C:\E5.txt (
                SET SEQUENCE=BDFGHIKMOZ
            ) ELSE (
                SET SEQUENCE=BCFGHIKMOZ
            )
        ) ELSE (
            IF EXIST C:\WINDOWS\system32\FBWFMGR.EXE (
                SET TARGET=C:\EmbeddedData\Firmware
                SET SEQUENCE=ABEFGHJKPZ
REM             IF EXIST C:\EmbeddedData\SecondRun.txt (
REM                 SET SEQUENCE=????
REM             ) ELSE (
REM                 SET SEQUENCE=????
REM             )
            ) ELSE (
                SET ERROR_MSG=No EWF or FBWF Files Detected - This program must be run on a K2 System only.
                GOTO ERROR_EXIT
            )
        )
    ) ELSE (
        IF "%~d0"=="C:" (
            IF EXIST C:\WINDOWS\system32\EWFMGR.EXE (
                SET SOURCE=C:\Firmware
                IF EXIST C:\E5.txt (
                    SET SEQUENCE=BDFGIKMOZ
                ) ELSE (
                    SET SEQUENCE=BCFGIKMOZ
                )
            ) ELSE (
                IF EXIST C:\WINDOWS\system32\FBWFMGR.EXE (
                    SET SOURCE=C:\EmbeddedData\Firmware
                    SET SEQUENCE=ABEFGJKPZ
REM                 IF EXIST C:\EmbeddedData\SecondRun.txt (
REM                     SET SEQUENCE=????
REM                 ) ELSE (
REM                     SET SEQUENCE=????
REM                 )
                ) ELSE (
                    SET ERROR_MSG=No EWF or FBWF Files Detected - This program must be run on a K2 System only.
                    GOTO ERROR_EXIT
                )
            )
        ) ELSE (
            SET ERROR_MSG=Invalid Drive - This program must be run from K2 drives E: or C: only.
            GOTO ERROR_EXIT
        )
    )

    GOTO ENTRY


::::::::::::::::::::
::  CONTROL LOOP  ::
::::::::::::::::::::
:CONTROL_LOOP

    SET SEQUENCE=%SEQUENCE:~1%

:ENTRY

    GOTO %SEQUENCE:~0,1%


:::::::::::::::::::::::::::::::::::::::::::::::::
::  KILL ANY RUNNING PRO2010NET.EXE PROCESSES  ::
:::::::::::::::::::::::::::::::::::::::::::::::::
:A

    TASKKILL /F /IM Pro2010Net.exe

    GOTO CONTROL_LOOP


:::::::::::::::::::::::::::::::::::::::::::
::  WRITE A MESSAGE TO THE VIDEO SCREEN  ::
:::::::::::::::::::::::::::::::::::::::::::
:B

    START "Bob4Writer" /WAIT "%SOURCE%\Support\Bob4Writer.exe" -m "                                                                                                                         -------------------------------------- |    PLEASE WAIT WHILE THE FIRMWARE    ||          IS BEING UPGRADED           | --------------------------------------                                          ** THIS PROCESS TAKES SEVERAL MINUTES^!                                          ** DO NOT TURN THE POWER OFF^!                                                   ** DO NOT REMOVE THE THUMB DRIVE^!"

    GOTO CONTROL_LOOP


:::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
::  MANAGE NON-FIRMWARE SUPPORT FILES ON PRE-E5 EPX SYSTEMS  ::
:::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
:C

    REM ******** Existing files to be removed: ********
    IF EXIST C:\WINDOWS\system32\Xboxhelp.chm DEL /F /Q C:\WINDOWS\system32\Xboxhelp.chm
    IF EXIST C:\WINDOWS\system32\XBoxStat.exe DEL /F /Q C:\WINDOWS\system32\XBoxStat.exe
    IF EXIST C:\WINDOWS\INF\oem*.inf          DEL /F /Q C:\WINDOWS\INF\oem*.inf
    IF EXIST C:\WINDOWS\INF\xusb21.cat        DEL /F /Q C:\WINDOWS\INF\xusb21.cat
    IF EXIST C:\WINDOWS\INF\X86\.             RD  /Q /S C:\WINDOWS\INF\X86

    REM ******** New files to be added: ********
    COPY   /Y    "%SOURCE%\Support\Xcopy.exe"                                     C:\WINDOWS\system32\*.*
    XCOPY  /R /Y "%SOURCE%\Support\attrib.exe"                                    C:\WINDOWS\system32\*.*
    XCOPY  /R /Y "%SOURCE%\Support\chkdsk.exe"                                    C:\WINDOWS\system32\*.*
    XCOPY  /R /Y "%SOURCE%\Support\fbwflib.dll"                                   C:\WINDOWS\system32\*.*
    XCOPY  /R /Y "%SOURCE%\Support\fltlib.dll"                                    C:\WINDOWS\system32\*.*
    XCOPY  /R /Y "%SOURCE%\Support\format.com"                                    C:\WINDOWS\system32\*.*
    XCOPY  /R /Y "%SOURCE%\Support\WdfCoInstaller01007.dll"                       C:\WINDOWS\system32\*.*
    XCOPY  /R /Y "%SOURCE%\Support\Xboxres.dll"                                   C:\WINDOWS\system32\*.*
    XCOPY  /R /Y "%SOURCE%\Support\xinput1_3.dll"                                 C:\WINDOWS\system32\*.*
    XCOPY  /R /Y "%SOURCE%\Support\Msft_Kernel_xusb21_01007.Wdf"                  C:\WINDOWS\system32\drivers\*.*
    ATTRIB +H     C:\WINDOWS\system32\drivers\Msft_Kernel_xusb21_01007.Wdf
    XCOPY  /R /Y "%SOURCE%\Support\MsftWdf_Kernel_01007_Coinstaller_Critical.Wdf" C:\WINDOWS\system32\drivers\*.*
    ATTRIB +H     C:\WINDOWS\system32\drivers\MsftWdf_Kernel_01007_Coinstaller_Critical.Wdf
    XCOPY  /R /Y "%SOURCE%\Support\wdf01000.sys"                                  C:\WINDOWS\system32\drivers\*.*
    XCOPY  /R /Y "%SOURCE%\Support\wdfldr.sys"                                    C:\WINDOWS\system32\drivers\*.*
    XCOPY  /R /Y "%SOURCE%\Support\WmBEnum.sys"                                   C:\WINDOWS\system32\drivers\*.*
    XCOPY  /R /Y "%SOURCE%\Support\WmVirHid.sys"                                  C:\WINDOWS\system32\drivers\*.*
    XCOPY  /R /Y "%SOURCE%\Support\WmXlCore.sys"                                  C:\WINDOWS\system32\drivers\*.*
    XCOPY  /R /Y "%SOURCE%\Support\xusb21.sys"                                    C:\WINDOWS\system32\drivers\*.*
    XCOPY  /R /Y "%SOURCE%\Support\WmVirHid.inf"                                  C:\WINDOWS\INF\*.*
    XCOPY  /R /Y "%SOURCE%\Support\xusb21.inf"                                    C:\WINDOWS\INF\*.*
    XCOPY  /R /Y "%SOURCE%\Support\Reinstall Firmware.lnk"                       "C:\Documents and Settings\user1\Desktop\*.*"

    GOTO CONTROL_LOOP


::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
::  MANAGE NON-FIRMWARE SUPPORT FILES ON POST-D4 EPX SYSTEMS  ::
::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
:D

    XCOPY /R /Y "%SOURCE%\Support\xusb21.inf" C:\WINDOWS\INF\*.*

    GOTO CONTROL_LOOP


::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
::  MANAGE NON-FIRMWARE SUPPORT FILES ON LX800 SYSTEMS  ::
::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
:E

    XCOPY /R /Y "%SOURCE%\Support\xusb21.inf" C:\WINDOWS\INF\*.*
    IF %COMMIT%  NEQ %DONTCOMMIT% (
        FBWFMGR /COMMIT C: \WINDOWS\INF\xusb21.inf
    )
    GOTO CONTROL_LOOP


:::::::::::::::::::::::::::
::  FORMAT THE D: DRIVE  ::
:::::::::::::::::::::::::::
:F

    REM ******** Save the existing persist file ********
    IF EXIST D:\ConfigurationFiles\Persist.txt XCOPY /R /Y D:\ConfigurationFiles\Persist.txt C:\*.*

    REM ******** Format the D: drive ********
    ECHO CUESD> C:\FormatPrompts.txt
    ECHO Y>> C:\FormatPrompts.txt
    FORMAT D: /V:CUESD /Q /X < C:\FormatPrompts.txt
    DEL /F /Q C:\FormatPrompts.txt

    GOTO CONTROL_LOOP


::::::::::::::::::::::::::::::::::
::  INSTALL ALL FIRMWARE FILES  ::
::::::::::::::::::::::::::::::::::
:G

    REM ******** Remove old firmware files ********
    DEL   /F /Q     C:\Pro2010Net.*
    DEL   /F /Q     C:\WINDOWS\system32\CTaskKeyHookDll.*

    REM ******** Install new firmware files ********
    XCOPY /R /Y    "%SOURCE%\Pro2010Net.exe"              C:\*.*
    XCOPY /E /R /Y "%SOURCE%\ConfigurationFiles"          D:\ConfigurationFiles\
    XCOPY /R /Y    "%SOURCE%\Support\CTaskKeyHookDll.dll" C:\WINDOWS\system32\*.*
    MD              D:\InspectionFiles

    REM ******** Restore the existing persist file ********
    IF EXIST C:\Persist.txt MOVE /Y C:\Persist.txt D:\ConfigurationFiles\LegacyPersist.txt

    GOTO CONTROL_LOOP


:::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
::  CREATE A BACKUP OF THE FIRMWARE FILES ON THE C: DRIVE  ::
:::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
:H

    IF EXIST "%TARGET%\." ( RD /Q /S "%TARGET%" )
    XCOPY /R /Y    "%SOURCE%\Pro2010Net.exe"     "%TARGET%\*.*"
    XCOPY /R /Y    "%SOURCE%\Upgrade.bat"        "%TARGET%\*.*"
    XCOPY /E /R /Y "%SOURCE%\ConfigurationFiles" "%TARGET%\ConfigurationFiles\"
    XCOPY /E /R /Y "%SOURCE%\Support"            "%TARGET%\Support\"

    GOTO CONTROL_LOOP


:::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
::  ADD REGISTRY KEYS ON EPX SYSTEMS                                   ::
:::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
::  - SUPPRESS UI (PREVENT ADD NEW HARDWARE WIZARD)                    ::
::  - DISABLE SELECTIVE SUSPEND (PREVENT USB POWER MANAGEMENT BY CPU)  ::
:::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
:I

    IF %COMMIT%  NEQ %DONTCOMMIT% (
      START "" /WAIT REGEDIT.EXE /S "%SOURCE%\Support\SuppressUI.reg"
      START "" /WAIT REGEDIT.EXE /S "%SOURCE%\Support\DisableSelectiveSuspend.reg"
    )

    GOTO CONTROL_LOOP


:::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
::  ADD REGISTRY KEYS ON LX800 SYSTEMS                                 ::
:::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
::  - DISABLE SELECTIVE SUSPEND (PREVENT USB POWER MANAGEMENT BY CPU)  ::
:::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
:J

    IF %COMMIT%  NEQ %DONTCOMMIT% (
        START "" /WAIT REGEDIT.EXE /S "%SOURCE%\Support\DisableSelectiveSuspend.reg"
        FBWFMGR /COMMIT C: \WINDOWS\system32\config\SYSTEM
        FBWFMGR /COMMIT C: \WINDOWS\system32\config\SYSTEM.LOG
    )

    GOTO CONTROL_LOOP


:::::::::::::::::::::::::::::::::::::::::::::::::::::::::
::  EDIT STARTUP FILE - CALL PRO2010NET.EXE AT BOOTUP  ::
:::::::::::::::::::::::::::::::::::::::::::::::::::::::::
:K

    DEL /F /Q "C:\Documents and Settings\All Users\Start Menu\Programs\Startup\*.*"
    ECHO START "Pro2010Net.exe" C:\Pro2010Net.exe> "C:\Documents and Settings\All Users\Start Menu\Programs\Startup\CuesStartup.bat"

    GOTO CONTROL_LOOP


:::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
::  EDIT STARTUP FILE - CALL UPGRADE.BAT AT BOOTUP ON LX800 SYSTEMS  ::
:::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
:L

    DEL /F /Q "C:\Documents and Settings\All Users\Start Menu\Programs\Startup\*.*"
    ECHO START "" C:\EmbeddedData\Firmware\Upgrade.bat> "C:\Documents and Settings\All Users\Start Menu\Programs\Startup\TempStartup.bat"

    GOTO CONTROL_LOOP


::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
::  EWFMGR - COMMIT ALL CHANGES AND DISABLE WRITE-PROTECTION  ::
::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
:M

    EWFMGR C: -COMMITANDDISABLE -LIVE

    GOTO CONTROL_LOOP


:::::::::::::::::::::::::::::::::::::::::::::::::::::::::
::  MANAGE SECOND RUN INDICATOR FILE ON LX800 SYSTEMS  ::
:::::::::::::::::::::::::::::::::::::::::::::::::::::::::
:N

    IF EXIST C:\EmbeddedData\SecondRun.txt (
        DEL /F /Q C:\EmbeddedData\SecondRun.txt
    ) ELSE (
        ECHO First run done^^!> C:\EmbeddedData\SecondRun.txt
    )

    GOTO CONTROL_LOOP


:::::::::::::::::::::::::::::::::::::::::::::::::::::
::  EWFMGR - ENABLE WRITE-PROTECTION ON NEXT BOOT  ::
:::::::::::::::::::::::::::::::::::::::::::::::::::::
:O

    EWFMGR C: -ENABLE

    GOTO CONTROL_LOOP


::::::::::::::::::::::::::::::::::::::::::::::::::::::
::  FBWFMGR - ENABLE WRITE-PROTECTION ON NEXT BOOT  ::
::::::::::::::::::::::::::::::::::::::::::::::::::::::
:P

    FBWFMGR /ENABLE

    GOTO CONTROL_LOOP


:::::::::::::::::::::::::::::::::::::::::::::::::::::::
::  FBWFMGR - DISABLE WRITE-PROTECTION ON NEXT BOOT  ::
:::::::::::::::::::::::::::::::::::::::::::::::::::::::
:Q

    FBWFMGR /DISABLE

    GOTO CONTROL_LOOP


::::::::::::::::::::::::::
::  SHUTDOWN - RESTART  ::
::::::::::::::::::::::::::
:Z

    START "Bob4Writer" /WAIT "%SOURCE%\Support\Bob4Writer.exe" -m "                                                                                                                         -------------------------------------- |    FILE INSTALLATION IS COMPLETE.    ||     THE SYSTEM IS NOW REBOOTING.     | --------------------------------------                                          ** THIS PROCESS TAKES SEVERAL MINUTES^!                                          ** DO NOT TURN THE POWER OFF^!                                                   ** WAIT 10 SECONDS,                                                             ** THEN REMOVE THE THUMB DRIVE^!"

    SHUTDOWN -R -T 00

    GOTO WAIT


::::::::::::::::::::::::::
::  ERROR EXIT ROUTINE  ::
::::::::::::::::::::::::::
:ERROR_EXIT

    ECHO.
    ECHO.
    ECHO ************************************************************
    ECHO ************************   ERROR^^!   ************************
    ECHO ************************************************************
    ECHO.
    ECHO %ERROR_MSG%
    ECHO.
    ECHO ************************************************************
    ECHO.

    GOTO WAIT


:::::::::::::::::
::  WAIT HERE  ::
:::::::::::::::::
:WAIT

    PAUSE
